@@ -34,9 +34,23 @@ impl FuzzyPath {
 	/// It is a logic error to construct a `FuzzyPath` from a string that is not correctly normalized.
 	///
 	/// To see the normalization implementation, see the `From<&str>` implementation for `FuzzyPath`
-	pub unsafe fn from_str_unchecked<S: Into<String>>(str: S) -> Self {
+	pub unsafe fn from_string_unchecked<S: Into<String>>(str: S) -> Self {
 		FuzzyPath(str.into())
 	}
+
+	/// Returns the underlying normalized `String` of the path.
+	///
+	/// This is lossy because not all paths are UTF-8 and it has been normalized.
+	pub fn into_string_lossy(self) -> String {
+		self.0
+	}
+
+	/// Returns the underlying normalized `String` of the path as a `&str`
+	///
+	/// This is lossy because not all paths are UTF-8 and it has been normalized.
+	pub fn as_str_lossy(&self) -> &str {
+		self.0.as_str()
+	}
 }
 impl From<&str> for FuzzyPath {
 	fn from(str: &str) -> Self {
@@ -72,6 +86,11 @@ impl From<String> for FuzzyPath {
 		string.as_str().into()
 	}
 }
+impl From<&String> for FuzzyPath {
+	fn from(string: &String) -> Self {
+		string.as_str().into()
+	}
+}
 impl From<FuzzyPath> for PathBuf {
 	fn from(fuzzy: FuzzyPath) -> Self {
 		PathBuf::from(fuzzy.0)
@@ -109,6 +128,11 @@ impl FromStr for FuzzyPath {
 		Ok(s.into())
 	}
 }
+impl ToString for FuzzyPath {
+	fn to_string(&self) -> String {
+		self.0.to_string()
+	}
+}
 
 #[cfg(feature = "serde")]
 mod serde;
